@@ -39,9 +39,6 @@ pub struct PipCompileCompatArgs {
     #[clap(long, hide = true)]
     client_cert: Option<String>,
 
-    #[clap(long, hide = true)]
-    trusted_host: Option<String>,
-
     #[clap(long, hide = true)]
     emit_trusted_host: bool,
 
@@ -118,15 +115,9 @@ impl CompatArgs for PipCompileCompatArgs {
             ));
         }
 
-        if self.trusted_host.is_some() {
-            return Err(anyhow!(
-                "pip-compile's `--trusted-host` is unsupported (uv always requires HTTPS)"
-            ));
-        }
-
         if self.emit_trusted_host {
             return Err(anyhow!(
-                "pip-compile's `--emit-trusted-host` is unsupported (uv always requires HTTPS)"
+                "pip-compile's `--emit-trusted-host` is unsupported"
             ));
         }
 
@@ -209,9 +200,6 @@ pub struct PipSyncCompatArgs {
     #[clap(short, long, hide = true)]
     ask: bool,
 
-    #[clap(long, hide = true)]
-    trusted_host: Option<String>,
-
     #[clap(long, hide = true)]
     python_executable: Option<String>,
 
@@ -265,12 +253,6 @@ impl CompatArgs for PipSyncCompatArgs {
             ));
         }
 
-        if self.trusted_host.is_some() {
-            return Err(anyhow!(
-                "pip-sync's `--trusted-host` is unsupported (uv always requires HTTPS)"
-            ));
-        }
-
         if self.config.is_some() {
             return Err(anyhow!(
                 "pip-sync's `--config` is unsupported (uv does not use a configuration file)"
