@@ -17,6 +17,7 @@ pub use sources::*;
 pub use target_triple::*;
 pub use trusted_host::*;
 pub use trusted_publishing::*;
+pub use vcs::*;
 
 mod authentication;
 mod build_options;
@@ -37,3 +38,4 @@ mod sources;
 mod target_triple;
 mod trusted_host;
 mod trusted_publishing;
+mod vcs;
