@@ -4,11 +4,11 @@ use std::path::Path;
 
 use itertools::Itertools;
 
-use distribution_types::{DistributionMetadata, Name, ResolvedDist, Verbatim, VersionOrUrlRef};
-use pep440_rs::Version;
-use pep508_rs::{split_scheme, MarkerTree, Scheme};
-use pypi_types::HashDigest;
+use uv_distribution_types::{DistributionMetadata, Name, ResolvedDist, Verbatim, VersionOrUrlRef};
 use uv_normalize::{ExtraName, PackageName};
+use uv_pep440::Version;
+use uv_pep508::{split_scheme, MarkerTree, Scheme};
+use uv_pypi_types::HashDigest;
 
 use crate::{
     requires_python::{RequiresPython, SimplifiedMarkerTree},
