@@ -5,18 +5,18 @@ use anyhow::Result;
 use itertools::Itertools;
 use owo_colors::OwoColorize;
 use serde::Serialize;
-use tracing::debug;
 use unicode_width::UnicodeWidthStr;
 
-use distribution_types::{Diagnostic, InstalledDist, Name};
 use uv_cache::Cache;
 use uv_cli::ListFormat;
+use uv_distribution_types::{Diagnostic, InstalledDist, Name};
 use uv_fs::Simplified;
 use uv_installer::SitePackages;
 use uv_normalize::PackageName;
 use uv_python::PythonRequest;
 use uv_python::{EnvironmentPreference, PythonEnvironment};
 
+use crate::commands::pip::operations::report_target_environment;
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
 
@@ -39,11 +39,7 @@ pub(crate) fn pip_list(
         cache,
     )?;
 
-    debug!(
-        "Using Python {} environment at {}",
-        environment.interpreter().python_version(),
-        environment.python_executable().user_display().cyan()
-    );
+    report_target_environment(&environment, cache, printer)?;
 
     // Build the installed index.
     let site_packages = SitePackages::from_environment(&environment)?;
