@@ -750,12 +750,14 @@ fn tool_run_list_installed() {
     uv_snapshot!(context.filters(), context.tool_run()
         .env("UV_TOOL_DIR", tool_dir.as_os_str())
         .env("XDG_BIN_HOME", bin_dir.as_os_str()), @r###"
-    success: true
-    exit_code: 0
+    success: false
+    exit_code: 2
     ----- stdout -----
+    Provide a command to run with `uv tool run <command>`.
+
+    See `uv tool run --help` for more information.
 
     ----- stderr -----
-    No tools installed
     "###);
 
     // Install `black`.
@@ -771,12 +773,16 @@ fn tool_run_list_installed() {
     uv_snapshot!(context.filters(), context.tool_run()
         .env("UV_TOOL_DIR", tool_dir.as_os_str())
         .env("XDG_BIN_HOME", bin_dir.as_os_str()), @r###"
-    success: true
-    exit_code: 0
+    success: false
+    exit_code: 2
     ----- stdout -----
-    black v24.2.0
-    - black
-    - blackd
+    Provide a command to run with `uv tool run <command>`.
+
+    The following tools are installed:
+
+    - black v24.2.0
+
+    See `uv tool run --help` for more information.
 
     ----- stderr -----
     "###);
@@ -891,9 +897,8 @@ fn tool_run_with_editable() -> anyhow::Result<()> {
     "###);
 
     // Requesting an editable requirement should install it in a layer, even if it satisfied
-    uv_snapshot!(context.filters(), context.tool_run().arg("--with-editable").arg("./src/anyio_local").arg("flask").arg("--version").env("UV_TOOL_DIR", tool_dir.as_os_str()).env("XDG_BIN_HOME", bin_dir.as_os_str())
-    
-    , @r###"
+    uv_snapshot!(context.filters(), context.tool_run().arg("--with-editable").arg("./src/anyio_local").arg("flask").arg("--version").env("UV_TOOL_DIR", tool_dir.as_os_str()).env("XDG_BIN_HOME", bin_dir.as_os_str()),
+    @r###"
     success: true
     exit_code: 0
     ----- stdout -----
